@@ -176,6 +176,10 @@ void DavixCopyInternal::copy(const Uri &src, const Uri &dst,
         suppressFinalHead = true;
     }
 
+    if(destination.compare(0, 3, "dav") == 0) {
+        destination.replace(0, 3, "http");
+    }
+
     // Perform COPY hopping through redirections
     HttpRequest* request = NULL;
     do {
@@ -248,8 +252,7 @@ void DavixCopyInternal::copy(const Uri &src, const Uri &dst,
             dlg_id.clear();
         }
 
-
-    } while (request->getAnswerHeader("Location", nextSrc));
+    } while (request->getAnswerHeader("Location", nextSrc) && request->getRequestCode() >= 300 && request->getRequestCode() < 400);
 
     if (!*error) {
         int responseStatus = request->getRequestCode();
@@ -291,7 +294,11 @@ void DavixCopyInternal::copy(const Uri &src, const Uri &dst,
 
     // Just wait for it to finish
     monitorPerformanceMarkers(request, error);
-    request->endRequest(error);
+    request->endRequest(&internalError);
+    if(internalError && !(*error) ) {
+        DavixError::propagatePrefixedError(error, internalError, __func__);
+    }
+
     delete request;
 }
 
