@@ -31,6 +31,8 @@
 #include <neon/neonsession.hpp>
 #include <fileops/fileutils.hpp>
 #include <fileops/AzureIO.hpp>
+#include <fileops/S3IO.hpp>
+#include <core/RedirectionResolver.hpp>
 
 
 
@@ -207,12 +209,12 @@ int NEONRequest::createRequest(DavixError** err){
 
     std::shared_ptr<Uri> redir_url;
     if(this->params.getTransparentRedirectionSupport()) {
-        redir_url = ContextExplorer::SessionFactoryFromContext(_c).redirectionResolve(_request_type, *_current);
+        redir_url = ContextExplorer::RedirectionResolverFromContext(_c).redirectionResolve(_request_type, *_current);
     }
 
     // performing an operation which could change the PFN? Clear all cache entries for selected URL
     if(_request_type == "DELETE" || _request_type == "MOVE") {
-        ContextExplorer::SessionFactoryFromContext(_c).redirectionClean(*_current.get());
+        ContextExplorer::RedirectionResolverFromContext(_c).redirectionClean(*_current.get());
     }
 
     if(redir_url.get() != NULL){
@@ -394,6 +396,15 @@ int NEONRequest::processRedirection(int neonCode, DavixError **err){
     return end_status;
 }
 
+static dav_ssize_t readFunction(int fd, void* buffer, dav_size_t size) {
+    dav_ssize_t ret = ::read(fd, buffer, size);
+    if(ret < 0) {
+        int myerr = errno;
+        DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_CHAIN, "Error in readFunction when attempting to read from fd {}: Return code {}, errno: {}", fd, ret, myerr);
+    }
+
+    return ret;
+}
 
 int NEONRequest::startRequest(DavixError **err){
     if( createRequest(err) < 0)
@@ -402,7 +413,10 @@ int NEONRequest::startRequest(DavixError **err){
 }
 
 int NEONRequest::negotiateRequest(DavixError** err){
+    std::string ugrs3post;
+    std::string ugrpluginid;
 
+    const uint64_t s3SizeLimit = (1024ull * 1024ull * 1024ull * 5ull);
     const int auth_retry_limit = params.getOperationRetry();
     int code, status, end_status = NE_RETRY;
     _last_read = -1;
@@ -450,7 +464,7 @@ int NEONRequest::negotiateRequest(DavixError** err){
             createError(status, err);
 
             cancelSessionReuse();
-            ContextExplorer::SessionFactoryFromContext(_c).redirectionClean(_request_type, *_orig);
+            ContextExplorer::RedirectionResolverFromContext(_c).redirectionClean(_request_type, *_orig);
             return -1;
         }
 
@@ -476,6 +490,38 @@ int NEONRequest::negotiateRequest(DavixError** err){
             case 302:
             case 303:
             case 307:
+
+                if(getAnswerHeader("x-ugrs3posturl", ugrs3post) &&
+                   getAnswerHeader("x-ugrpluginid", ugrpluginid) &&
+                   !ugrs3post.empty() && (_content_len >= s3SizeLimit || _current->fragmentParamExists("forceMultiPart")) ) {
+                    // Ugly workaround for s3 + multi-part upload + dynafed
+                    DAVIX_SLOG(DAVIX_LOG_DEBUG, DAVIX_LOG_HTTP, "Initiating dynafed-assisted multi-part upload to S3, posturl: {}, pluginid: {}", ugrs3post, ugrpluginid);
+                    IOChainContext iocontext(_c, *_current, &params);
+
+                    using std::placeholders::_1;
+                    using std::placeholders::_2;
+
+                    S3IO s3io;
+                    DataProviderFun provider;
+
+                    if(_fd_content > 0) {
+                        provider = std::bind(readFunction, _fd_content, _1, _2);
+                    }
+                    else if(_content_provider.callback) {
+                        provider = std::bind(iocontext_content_provider, _content_provider.callback, _content_provider.udata, _1, _2);
+                    }
+
+                    requestCleanup();
+                    DavixError::clearError(err);
+                    endRequest(NULL);
+
+                    _early_termination = true;
+                    s3io.performUgrS3MultiPart(iocontext, ugrs3post, ugrpluginid, provider, _content_len, &_early_termination_error);
+
+                    if(!err) return 0;
+                    return -1;
+                }
+
                 if( (end_status = processRedirection(status, err)) <0){
                    return -1;
                 }
@@ -559,7 +605,7 @@ int NEONRequest::negotiateRequest(DavixError** err){
 //
 bool NEONRequest::requestCleanup(){
     // cleanup redirection
-    ContextExplorer::SessionFactoryFromContext(_c).redirectionClean(_request_type, *_orig);
+    ContextExplorer::RedirectionResolverFromContext(_c).redirectionClean(_request_type, *_orig);
 
     // disable recycling
     // server supporting broken pipelining will trigger if reused
@@ -592,7 +638,7 @@ int NEONRequest::redirectRequest(DavixError **err){
     old_uri = _current;
     _current= std::shared_ptr<Uri>(new Uri(dst_uri));
     ne_free(dst_uri);
-    ContextExplorer::SessionFactoryFromContext(_c).addRedirection(_request_type, *old_uri, _current);
+    ContextExplorer::RedirectionResolverFromContext(_c).addRedirection(_request_type, *old_uri, _current);
 
 
     // recycle old request and session
@@ -807,7 +853,7 @@ dav_ssize_t NEONRequest::readSegment(char* p_buff, dav_size_t size_read, bool st
     do{
         tmp_ret= readBlock(p_buff, s_read, &tmp_err);
 
-        if(tmp_ret > 0 && std::find(p_buff, p_buff+tmp_ret, '\n') != p_buff+tmp_ret) {
+        if(tmp_ret > 0 && stop_at_line_boundary && std::find(p_buff, p_buff+tmp_ret, '\n') != p_buff+tmp_ret) {
             early_stop = true;
         }
 
