@@ -25,9 +25,7 @@
 #include <map>
 #include <mutex>
 #include <utils/davix_uri.hpp>
-
 #include <neon/neonrequest.hpp>
-#include <alibxx/containers/cache.hpp>
 
 namespace Davix {
 
@@ -50,20 +48,6 @@ public:
     */
     int storeNeonSession(ne_session *sess);
 
-    //
-    // Redirecton caching
-    //
-
-    void addRedirection( const std::string & method, const Uri & origin, std::shared_ptr<Uri> dest);
-
-    // try to find cached redirection, resolve a full chain
-    std::shared_ptr<Uri> redirectionResolve(const std::string & method, const Uri & origin);
-    // try to find a cached redirection, resolve only one element
-    std::shared_ptr<Uri> redirectionResolveSingle(const std::string & method, const Uri & origin);
-
-    void redirectionClean(const std::string & method, const Uri & origin);
-    void redirectionClean(const Uri & origin);
-
     //
     // opts
     //
@@ -78,17 +62,11 @@ private:
     // session pool
     std::multimap<std::string, ne_session*> _sess_map;
     std::mutex _sess_mut;
-    bool _session_caching, _redir_caching;
-
-    // redirection pool
-    Cache<std::pair<std::string, std::string>, Uri> _redirCache;
+    bool _session_caching;
 
     void internal_release_session_handle(ne_session* sess);
     ne_session* create_session(const RequestParams & params, const std::string & protocol, const std::string &host, unsigned int port);
     ne_session* create_recycled_session(const RequestParams & params, const std::string & protocol, const std::string &host, unsigned int port);
-
-    std::shared_ptr<Uri> redirectionResolveSingleIntern(const std::string & method, const Uri & origin);
-
 };
 
 void parse_http_neon_url(const std::string & url, std::string & protocol,
